hive sql 转 clickhouse sql
--------------------------

使用方法： 
-----------

\`\`\`ruby import HiveToClickhouse

if **name** == '**main**\ ': hive\_sql = '' news\_sql =
HiveToClickhouse.execute(hive\_sql)
